## A simple game inspired by Frogger
##
## Keith O'Hara <kohara@bard.edu>
## April 2011

from myro import *
import random
from macGamepad import *

class Player:
    ''' The main player class in our frogger game.
        The player can move around the screen in both dimensions'''

    def __init__(self, p, win):
        ''' creates a player in the middle of the GraphWin 'win'.
            Uses the Picture 'p' as the player's appearance'''
        self.speed = 10
        self.alive = True
        self.win = win
        center = Point(win.getWidth()/2, win.getHeight()/2)
        self.appearance = Image(center, makePixmap(p))
        self.appearance.draw(win)

    def move(self, dx, dy):
        ''' move the player relatively by dx and dy
            the player wraps around if it reaches the left or
            right of the screen, it dies if it reaches the top
            or bottom'''
        self.appearance.move(self.speed*dx, self.speed*dy)
        p1 = self.appearance.getP1()
        p2 = self.appearance.getP2()
        if p2.getX() < 0:
            self.appearance.move(self.win.getWidth(), 0)
        elif p1.getX() > self.win.getWidth():
            self.appearance.move(-self.win.getWidth(), 0)
        if p1.getY() < 0 or p2.getY() > self.win.getHeight():
            self.alive = False
                
win = GraphWin("game", 500, 500)
win.setBackground("black")

#http://www.openclipart.org/detail/2112
frog = Player(makePicture("frog.png"), win)

while frog.alive:
    movement = getGamepadNow("axis")
    frog.move(movement[0], movement[1])

# create a game over message
center = Point(win.getWidth()/2, win.getHeight()/2)
congrats = Text(center, "Game Over!")
congrats.setFill("yellow")
congrats.setSize(32)
congrats.draw(win)
