## A simple game inspired by Frogger
##
## Keith O'Hara <kohara@bard.edu>
## April 2011

from myro import *
import random
from macGamepad import *

class Car:
    ''' The enemy class in our frogger game.
        The car moves horizontally with some random speed'''
      
    MAX_SIZE=60
    MIN_SIZE=20
    SPEED=5
    def __init__(self, win):
        ''' creates a car randomly placed in the GraphWin 'win'.
            The car's color is randomly chosen as blue, orange, or red'''
        self.win = win
        x = win.getWidth()*random.random()
        y = win.getHeight()*random.random()
        width = random.uniform(Car.MIN_SIZE, Car.MAX_SIZE)
        height = random.uniform(Car.MIN_SIZE, Car.MAX_SIZE)
        self.appearance = Rectangle(Point(x, y),
                                    Point(x + width, y + height))
        self.appearance.setFill(random.choice(["blue", "orange", "red"]))
        self.appearance.setOutline("gray")
        self.vx = random.uniform(-Car.SPEED, Car.SPEED)
        self.vy = 0
        self.appearance.draw(win)

    def step(self):
        ''' move the horizontally by car by its speed
            the car wraps around if it reaches the left or
            right of the screen.'''
        self.appearance.move(self.vx, self.vy)
        p1 = self.appearance.getP1()
        if p1.getX() < 0:
            self.appearance.move(self.win.getWidth(), 0)
        elif p1.getX() > self.win.getWidth():
            self.appearance.move(-self.win.getWidth(), 0)

    def checkCollision(self, p1, p2):
        ''' detect if this object is colliding with a rectangle with
            the bounding box p1 and p2. returns True if the objects
            are colliding'''
        myp1 = self.appearance.getP1()
        myp2 = self.appearance.getP2()
        return myp1.getX() < p2.x and myp2.getX() > p1.x\
               and myp1.getY() < p2.y and myp2.getY() > p1.y


class Player:
    ''' The main player class in our frogger game.
        The player can move around the screen in both dimensions'''
    
    def __init__(self, p, win):
        ''' creates a player in the middle of the GraphWin 'win'.
            Uses the Picture 'p' as the player's appearance'''
        self.speed = 10
        self.win = win
        self.state = "Running"
        center = Point(win.getWidth()/2, win.getHeight())
        self.appearance = Image(center, makePixmap(p))
        self.appearance.draw(win)

    def move(self, dx, dy, cars):
        ''' move the player relatively by dx and dy
            the player wraps around if it reaches the left or
            right of the screen, it dies if it reaches the top
            or bottom or if it collides with a car'''
         
        self.appearance.move(self.speed*dx, self.speed*dy)

        p1 = self.appearance.getP1()
        p2 = self.appearance.getP2()
        if p2.getX() < 0:
            self.appearance.move(self.win.getWidth(), 0)
        elif p1.getX() > self.win.getWidth():
            self.appearance.move(-self.win.getWidth(), 0)
        if p1.getY() < 0 or p1.getY() > self.win.getHeight():
            self.state = "Finished"

        for car in cars:
            if car.checkCollision(p1, p2):
                win.setBackground('red')
                self.state = "Dead"
                
                
win = GraphWin("game", 500, 500)
win.setBackground("black")

#http://www.openclipart.org/detail/2112
frog = Player(makePicture("frog.png"), win)

# Add a bunch of cars to our game
cars = []
for i in range(10):
    a = Car(win)
    cars.append(a)

while frog.state == "Running":
    movement = getGamepadNow("axis")
    frog.move(movement[0], movement[1], cars)
    for car in cars:
        car.step()

# create a game over message

if frog.state == "Finished":
    center = Point(win.getWidth()/2, win.getHeight()/2)
    congrats = Text(center, "Congratulations!")
    congrats.setFill("yellow")
    congrats.setSize(32)
    congrats.draw(win)
else:
    center = Point(win.getWidth()/2, win.getHeight()/2)
    congrats = Text(center, "SPLAT!")
    congrats.setFill("white")
    congrats.setSize(32)
    congrats.draw(win) 
